@@ -7,6 +7,7 @@ from enum import Enum
 from dagster import check
 from dagster.core.errors import DagsterInvalidAssetKey
 from dagster.serdes import Persistable, whitelist_for_persistence
+from dagster.utils.backcompat import experimental_arg_warning
 
 from .utils import DEFAULT_OUTPUT
 
@@ -15,9 +16,9 @@ def last_file_comp(path):
     return os.path.basename(os.path.normpath(path))
 
 
-ASSET_KEY_REGEX = re.compile('^[a-zA-Z0-9_]+$')  # alphanumeric, _, -, .
-ASSET_KEY_SPLIT_REGEX = re.compile('[^a-zA-Z0-9_]')
-ASSET_KEY_STRUCTURED_DELIMITER = '.'
+ASSET_KEY_REGEX = re.compile("^[a-zA-Z0-9_]+$")  # alphanumeric, _, -, .
+ASSET_KEY_SPLIT_REGEX = re.compile("[^a-zA-Z0-9_]")
+ASSET_KEY_STRUCTURED_DELIMITER = "."
 
 
 def validate_asset_key_string(s):
@@ -42,8 +43,8 @@ def validate_structured_asset_key(l):
 
 
 @whitelist_for_persistence
-class AssetKey(namedtuple('_AssetKey', 'path'), Persistable):
-    ''' Object representing the structure of an asset key.  Takes in a sanitized string, list of
+class AssetKey(namedtuple("_AssetKey", "path"), Persistable):
+    """ Object representing the structure of an asset key.  Takes in a sanitized string, list of
     strings, or tuple of strings.
 
     Example usage:
@@ -57,23 +58,23 @@ class AssetKey(namedtuple('_AssetKey', 'path'), Persistable):
     Args:
         path (str|str[]|str()): String, list of strings, or tuple of strings.  A list of strings
             represent the hierarchical structure of the asset_key.
-    '''
+    """
 
     def __new__(cls, path=None):
         if check.is_str(path):
             path = [validate_asset_key_string(path)]
         elif isinstance(path, list):
-            path = validate_structured_asset_key(check.list_param(path, 'path', of_type=str))
+            path = validate_structured_asset_key(check.list_param(path, "path", of_type=str))
         else:
-            path = validate_structured_asset_key(check.tuple_param(path, 'path', of_type=str))
+            path = validate_structured_asset_key(check.tuple_param(path, "path", of_type=str))
 
         return super(AssetKey, cls).__new__(cls, path=path)
 
     def __str__(self):
-        return 'AssetKey({})'.format(self.to_string())
+        return "AssetKey({})".format(self.to_string())
 
     def __repr__(self):
-        return 'AssetKey({})'.format(self.to_string())
+        return "AssetKey({})".format(self.to_string())
 
     def __hash__(self):
         return hash(tuple(self.path))
@@ -96,16 +97,16 @@ class AssetKey(namedtuple('_AssetKey', 'path'), Persistable):
 
     @staticmethod
     def from_graphql_input(asset_key):
-        if asset_key and asset_key.get('path'):
-            return AssetKey(asset_key.get('path'))
+        if asset_key and asset_key.get("path"):
+            return AssetKey(asset_key.get("path"))
         return None
 
 
 @whitelist_for_persistence
 class EventMetadataEntry(
-    namedtuple('_EventMetadataEntry', 'label description entry_data'), Persistable
+    namedtuple("_EventMetadataEntry", "label description entry_data"), Persistable
 ):
-    '''The standard structure for describing metadata for Dagster events.
+    """The standard structure for describing metadata for Dagster events.
 
     Lists of objects of this type can be passed as arguments to Dagster events and will be displayed
     in Dagit and other tooling.
@@ -116,55 +117,55 @@ class EventMetadataEntry(
         entry_data (Union[TextMetadataEntryData, UrlMetadataEntryData, PathMetadataEntryData, JsonMetadataEntryData, MarkdownMetadataEntryData]):
             Typed metadata entry data. The different types allow for customized display in tools
             like dagit.
-    '''
+    """
 
     def __new__(cls, label, description, entry_data):
         return super(EventMetadataEntry, cls).__new__(
             cls,
-            check.str_param(label, 'label'),
-            check.opt_str_param(description, 'description'),
-            check.inst_param(entry_data, 'entry_data', EntryDataUnion),
+            check.str_param(label, "label"),
+            check.opt_str_param(description, "description"),
+            check.inst_param(entry_data, "entry_data", EntryDataUnion),
         )
 
     @staticmethod
     def text(text, label, description=None):
-        '''Static constructor for a metadata entry containing text as
+        """Static constructor for a metadata entry containing text as
         :py:class:`TextMetadataEntryData`.
 
         Args:
             text (Optional[str]): The text of this metadata entry.
             label (str): Short display label for this metadata entry.
             description (Optional[str]): A human-readable description of this metadata entry.
-        '''
+        """
         return EventMetadataEntry(label, description, TextMetadataEntryData(text))
 
     @staticmethod
     def url(url, label, description=None):
-        '''Static constructor for a metadata entry containing a URL as
+        """Static constructor for a metadata entry containing a URL as
         :py:class:`UrlMetadataEntryData`.
 
         Args:
             url (Optional[str]): The URL contained by this metadata entry.
             label (str): Short display label for this metadata entry.
             description (Optional[str]): A human-readable description of this metadata entry.
-        '''
+        """
         return EventMetadataEntry(label, description, UrlMetadataEntryData(url))
 
     @staticmethod
     def path(path, label, description=None):
-        '''Static constructor for a metadata entry containing a path as
+        """Static constructor for a metadata entry containing a path as
         :py:class:`PathMetadataEntryData`.
 
         Args:
             path (Optional[str]): The path contained by this metadata entry.
             label (str): Short display label for this metadata entry.
             description (Optional[str]): A human-readable description of this metadata entry.
-        '''
+        """
         return EventMetadataEntry(label, description, PathMetadataEntryData(path))
 
     @staticmethod
     def fspath(path, label=None, description=None):
-        '''Static constructor for a metadata entry containing a filesystem path as
+        """Static constructor for a metadata entry containing a filesystem path as
         :py:class:`PathMetadataEntryData`.
 
         Args:
@@ -172,37 +173,37 @@ class EventMetadataEntry(
             label (str): Short display label for this metadata entry. Defaults to the
                 base name of the path.
             description (Optional[str]): A human-readable description of this metadata entry.
-        '''
+        """
         return EventMetadataEntry.path(
             path, label if label is not None else last_file_comp(path), description
         )
 
     @staticmethod
     def json(data, label, description=None):
-        '''Static constructor for a metadata entry containing JSON data as
+        """Static constructor for a metadata entry containing JSON data as
         :py:class:`JsonMetadataEntryData`.
 
         Args:
             data (Optional[Dict[str, Any]]): The JSON data contained by this metadata entry.
             label (str): Short display label for this metadata entry.
             description (Optional[str]): A human-readable description of this metadata entry.
-        '''
+        """
         return EventMetadataEntry(label, description, JsonMetadataEntryData(data))
 
     @staticmethod
     def md(md_str, label, description=None):
-        '''Static constructor for a metadata entry containing markdown.
+        """Static constructor for a metadata entry containing markdown.
 
         Args:
             md_str (Optional[str]): The markdown contained by this metadata entry.
             label (str): Short display label for this metadata entry.
             description (Optional[str]): A human-readable description of this metadata entry.
-        '''
+        """
         return EventMetadataEntry(label, description, MarkdownMetadataEntryData(md_str))
 
     @staticmethod
     def python_artifact(python_artifact, label, description=None):
-        check.callable_param(python_artifact, 'python_artifact')
+        check.callable_param(python_artifact, "python_artifact")
         return EventMetadataEntry(
             label,
             description,
@@ -211,104 +212,104 @@ class EventMetadataEntry(
 
     @staticmethod
     def float(value, label, description=None):
-        '''Static constructor for a metadata entry containing float as
+        """Static constructor for a metadata entry containing float as
         :py:class:`FloatMetadataEntryData`.
 
         Args:
             value (Optional[float]): The float value contained by this metadata entry.
             label (str): Short display label for this metadata entry.
             description (Optional[str]): A human-readable description of this metadata entry.
-        '''
-        check.opt_float_param(value, 'value')
+        """
+        check.opt_float_param(value, "value")
         return EventMetadataEntry(label, description, FloatMetadataEntryData(value))
 
 
 @whitelist_for_persistence
-class TextMetadataEntryData(namedtuple('_TextMetadataEntryData', 'text'), Persistable):
-    '''Container class for text metadata entry data.
+class TextMetadataEntryData(namedtuple("_TextMetadataEntryData", "text"), Persistable):
+    """Container class for text metadata entry data.
 
     Args:
         text (Optional[str]): The text data.
-    '''
+    """
 
     def __new__(cls, text):
         return super(TextMetadataEntryData, cls).__new__(
-            cls, check.opt_str_param(text, 'text', default='')
+            cls, check.opt_str_param(text, "text", default="")
         )
 
 
 @whitelist_for_persistence
-class UrlMetadataEntryData(namedtuple('_UrlMetadataEntryData', 'url'), Persistable):
-    '''Container class for URL metadata entry data.
+class UrlMetadataEntryData(namedtuple("_UrlMetadataEntryData", "url"), Persistable):
+    """Container class for URL metadata entry data.
 
     Args:
         url (Optional[str]): The URL as a string.
-    '''
+    """
 
     def __new__(cls, url):
         return super(UrlMetadataEntryData, cls).__new__(
-            cls, check.opt_str_param(url, 'url', default='')
+            cls, check.opt_str_param(url, "url", default="")
         )
 
 
 @whitelist_for_persistence
-class PathMetadataEntryData(namedtuple('_PathMetadataEntryData', 'path'), Persistable):
-    '''Container class for path metadata entry data.
+class PathMetadataEntryData(namedtuple("_PathMetadataEntryData", "path"), Persistable):
+    """Container class for path metadata entry data.
 
     Args:
         path (Optional[str]): The path as a string.
-    '''
+    """
 
     def __new__(cls, path):
         return super(PathMetadataEntryData, cls).__new__(
-            cls, check.opt_str_param(path, 'path', default='')
+            cls, check.opt_str_param(path, "path", default="")
         )
 
 
 @whitelist_for_persistence
-class JsonMetadataEntryData(namedtuple('_JsonMetadataEntryData', 'data'), Persistable):
-    '''Container class for JSON metadata entry data.
+class JsonMetadataEntryData(namedtuple("_JsonMetadataEntryData", "data"), Persistable):
+    """Container class for JSON metadata entry data.
 
     Args:
         data (Optional[Dict[str, Any]]): The JSON data.
-    '''
+    """
 
     def __new__(cls, data):
         return super(JsonMetadataEntryData, cls).__new__(
-            cls, check.opt_dict_param(data, 'data', key_type=str)
+            cls, check.opt_dict_param(data, "data", key_type=str)
         )
 
 
 @whitelist_for_persistence
-class MarkdownMetadataEntryData(namedtuple('_MarkdownMetadataEntryData', 'md_str'), Persistable):
-    '''Container class for markdown metadata entry data.
+class MarkdownMetadataEntryData(namedtuple("_MarkdownMetadataEntryData", "md_str"), Persistable):
+    """Container class for markdown metadata entry data.
 
     Args:
         md_str (Optional[str]): The markdown as a string.
-    '''
+    """
 
     def __new__(cls, md_str):
         return super(MarkdownMetadataEntryData, cls).__new__(
-            cls, check.opt_str_param(md_str, 'md_str', default='')
+            cls, check.opt_str_param(md_str, "md_str", default="")
         )
 
 
 @whitelist_for_persistence
 class PythonArtifactMetadataEntryData(
-    namedtuple('_PythonArtifactMetadataEntryData', 'module name'), Persistable
+    namedtuple("_PythonArtifactMetadataEntryData", "module name"), Persistable
 ):
     def __new__(cls, module, name):
         return super(PythonArtifactMetadataEntryData, cls).__new__(
-            cls, check.str_param(module, 'module'), check.str_param(name, 'name')
+            cls, check.str_param(module, "module"), check.str_param(name, "name")
         )
 
 
 @whitelist_for_persistence
-class FloatMetadataEntryData(namedtuple('_FloatMetadataEntryData', 'value'), Persistable):
+class FloatMetadataEntryData(namedtuple("_FloatMetadataEntryData", "value"), Persistable):
     def __new__(cls, value):
-        check.opt_float_param(value, 'value')
+        check.opt_float_param(value, "value")
         return super(FloatMetadataEntryData, cls).__new__(
-            cls, check.opt_float_param(value, 'value')
+            cls, check.opt_float_param(value, "value")
         )
 
 
@@ -323,8 +324,8 @@ EntryDataUnion = (
 )
 
 
-class Output(namedtuple('_Output', 'value output_name')):
-    '''Event corresponding to one of a solid's outputs.
+class Output(namedtuple("_Output", "value output_name address")):
+    """Event corresponding to one of a solid's outputs.
 
     Solid compute functions must explicitly yield events of this type when they have more than
     one output, or when they also yield events of other types, or when defining a solid using the
@@ -338,17 +339,27 @@ class Output(namedtuple('_Output', 'value output_name')):
         value (Any): The value returned by the compute function.
         output_name (Optional[str]): Name of the corresponding output definition. (default:
             "result")
-    '''
+        address (str): (Experimental) A string that can be provided to a storage system to
+            store/retrieve the outputted value.
+    """
 
-    def __new__(cls, value, output_name=DEFAULT_OUTPUT):
-        return super(Output, cls).__new__(cls, value, check.str_param(output_name, 'output_name'))
+    def __new__(cls, value, output_name=DEFAULT_OUTPUT, address=None):
+        if address:
+            experimental_arg_warning("address", "Output.__new__")
+
+        return super(Output, cls).__new__(
+            cls,
+            value,
+            check.str_param(output_name, "output_name"),
+            check.opt_str_param(address, "address"),
+        )
 
 
 @whitelist_for_persistence
 class AssetMaterialization(
-    namedtuple('_AssetMaterialization', 'asset_key description metadata_entries'), Persistable
+    namedtuple("_AssetMaterialization", "asset_key description metadata_entries"), Persistable,
 ):
-    '''Event indicating that a solid has materialized an asset.
+    """Event indicating that a solid has materialized an asset.
 
     Solid compute functions may yield events of this type whenever they wish to indicate to the
     Dagster framework (and the end user) that they have produced a materialized value as a
@@ -365,11 +376,11 @@ class AssetMaterialization(
         description (Optional[str]): A longer human-radable description of the materialized value.
         metadata_entries (Optional[List[EventMetadataEntry]]): Arbitrary metadata about the
             materialized value.
-    '''
+    """
 
     def __new__(cls, asset_key, description=None, metadata_entries=None):
         if isinstance(asset_key, AssetKey):
-            check.inst_param(asset_key, 'asset_key', AssetKey)
+            check.inst_param(asset_key, "asset_key", AssetKey)
         elif check.is_str(asset_key):
             asset_key = AssetKey(parse_asset_key_string(asset_key))
         elif isinstance(asset_key, list):
@@ -382,7 +393,7 @@ class AssetMaterialization(
         return super(AssetMaterialization, cls).__new__(
             cls,
             asset_key=asset_key,
-            description=check.opt_str_param(description, 'description'),
+            description=check.opt_str_param(description, "description"),
             metadata_entries=check.opt_list_param(
                 metadata_entries, metadata_entries, of_type=EventMetadataEntry
             ),
@@ -394,12 +405,12 @@ class AssetMaterialization(
 
     @staticmethod
     def file(path, description=None, asset_key=None):
-        '''Static constructor for standard materializations corresponding to files on disk.
+        """Static constructor for standard materializations corresponding to files on disk.
 
         Args:
             path (str): The path to the file.
             description (Optional[str]): A human-readable description of the materialization.
-        '''
+        """
         if not asset_key:
             asset_key = path
 
@@ -412,9 +423,9 @@ class AssetMaterialization(
 
 @whitelist_for_persistence
 class Materialization(
-    namedtuple('_Materialization', 'label description metadata_entries asset_key'), Persistable
+    namedtuple("_Materialization", "label description metadata_entries asset_key"), Persistable
 ):
-    '''Event indicating that a solid has materialized a value.
+    """Event indicating that a solid has materialized a value.
 
     Solid compute functions may yield events of this type whenever they wish to indicate to the
     Dagster framework (and the end user) that they have produced a materialized value as a
@@ -431,7 +442,7 @@ class Materialization(
             materialized value.
         asset_key (Optional[str|AssetKey]): An optional parameter to identify the materialized asset
             across pipeline runs
-    '''
+    """
 
     def __new__(
         cls,
@@ -444,23 +455,23 @@ class Materialization(
         if asset_key and check.is_str(asset_key):
             asset_key = AssetKey(parse_asset_key_string(asset_key))
         else:
-            check.opt_inst_param(asset_key, 'asset_key', AssetKey)
+            check.opt_inst_param(asset_key, "asset_key", AssetKey)
 
         if not label:
             check.param_invariant(
                 asset_key and asset_key.path,
-                'label',
-                'Either label or asset_key with a path must be provided',
+                "label",
+                "Either label or asset_key with a path must be provided",
             )
             label = asset_key.to_string()
 
         if not skip_deprecation_warning:
-            warnings.warn('`Materialization` is deprecated; use `AssetMaterialization` instead.')
+            warnings.warn("`Materialization` is deprecated; use `AssetMaterialization` instead.")
 
         return super(Materialization, cls).__new__(
             cls,
-            label=check.str_param(label, 'label'),
-            description=check.opt_str_param(description, 'description'),
+            label=check.str_param(label, "label"),
+            description=check.opt_str_param(description, "description"),
             metadata_entries=check.opt_list_param(
                 metadata_entries, metadata_entries, of_type=EventMetadataEntry
             ),
@@ -469,12 +480,12 @@ class Materialization(
 
     @staticmethod
     def file(path, description=None, asset_key=None):
-        '''Static constructor for standard materializations corresponding to files on disk.
+        """Static constructor for standard materializations corresponding to files on disk.
 
         Args:
             path (str): The path to the file.
             description (Optional[str]): A human-readable description of the materialization.
-        '''
+        """
         return Materialization(
             label=last_file_comp(path),
             description=description,
@@ -491,9 +502,9 @@ class Materialization(
 
 @whitelist_for_persistence
 class ExpectationResult(
-    namedtuple('_ExpectationResult', 'success label description metadata_entries'), Persistable
+    namedtuple("_ExpectationResult", "success label description metadata_entries"), Persistable
 ):
-    '''Event corresponding to a data quality test.
+    """Event corresponding to a data quality test.
 
     Solid compute functions may yield events of this type whenever they wish to indicate to the
     Dagster framework (and the end user) that a data quality test has produced a (positive or
@@ -505,14 +516,14 @@ class ExpectationResult(
         description (Optional[str]): A longer human-readable description of the expectation.
         metadata_entries (Optional[List[EventMetadataEntry]]): Arbitrary metadata about the
             expectation.
-    '''
+    """
 
     def __new__(cls, success, label=None, description=None, metadata_entries=None):
         return super(ExpectationResult, cls).__new__(
             cls,
-            success=check.bool_param(success, 'success'),
-            label=check.opt_str_param(label, 'label', 'result'),
-            description=check.opt_str_param(description, 'description'),
+            success=check.bool_param(success, "success"),
+            label=check.opt_str_param(label, "label", "result"),
+            description=check.opt_str_param(description, "description"),
             metadata_entries=check.opt_list_param(
                 metadata_entries, metadata_entries, of_type=EventMetadataEntry
             ),
@@ -520,8 +531,8 @@ class ExpectationResult(
 
 
 @whitelist_for_persistence
-class TypeCheck(namedtuple('_TypeCheck', 'success description metadata_entries'), Persistable):
-    '''Event corresponding to a successful typecheck.
+class TypeCheck(namedtuple("_TypeCheck", "success description metadata_entries"), Persistable):
+    """Event corresponding to a successful typecheck.
 
     Events of this type should be returned by user-defined type checks when they need to encapsulate
     additional metadata about a type check's success or failure. (i.e., when using
@@ -535,13 +546,13 @@ class TypeCheck(namedtuple('_TypeCheck', 'success description metadata_entries')
         description (Optional[str]): A human-readable description of the type check.
         metadata_entries (Optional[List[EventMetadataEntry]]): Arbitrary metadata about the
             type check.
-    '''
+    """
 
     def __new__(cls, success, description=None, metadata_entries=None):
         return super(TypeCheck, cls).__new__(
             cls,
-            success=check.bool_param(success, 'success'),
-            description=check.opt_str_param(description, 'description'),
+            success=check.bool_param(success, "success"),
+            description=check.opt_str_param(description, "description"),
             metadata_entries=check.opt_list_param(
                 metadata_entries, metadata_entries, of_type=EventMetadataEntry
             ),
@@ -549,7 +560,7 @@ class TypeCheck(namedtuple('_TypeCheck', 'success description metadata_entries')
 
 
 class Failure(Exception):
-    '''Event indicating solid failure.
+    """Event indicating solid failure.
 
     Raise events of this type from within solid compute functions or custom type checks in order to
     indicate an unrecoverable failure in user code to the Dagster machinery and return
@@ -559,18 +570,18 @@ class Failure(Exception):
         description (Optional[str]): A human-readable description of the failure.
         metadata_entries (Optional[List[EventMetadataEntry]]): Arbitrary metadata about the
             failure.
-    '''
+    """
 
     def __init__(self, description=None, metadata_entries=None):
         super(Failure, self).__init__(description)
-        self.description = check.opt_str_param(description, 'description')
+        self.description = check.opt_str_param(description, "description")
         self.metadata_entries = check.opt_list_param(
-            metadata_entries, 'metadata_entries', of_type=EventMetadataEntry
+            metadata_entries, "metadata_entries", of_type=EventMetadataEntry
         )
 
 
 class RetryRequested(Exception):  # base exception instead?
-    '''
+    """
     EXPERIMENTAL: A simple tool for retrying the execution of a step in dagster.
 
     Args:
@@ -579,28 +590,28 @@ class RetryRequested(Exception):  # base exception instead?
         seconds_to_wait (Optional[int]):
             Seconds to wait before restarting the step after putting the step in
             to the up_for_retry state
-    '''
+    """
 
     def __init__(self, max_retries=1, seconds_to_wait=None):
         super(RetryRequested, self).__init__()
-        self.max_retries = check.int_param(max_retries, 'max_retries')
-        self.seconds_to_wait = check.opt_int_param(seconds_to_wait, 'seconds_to_wait')
+        self.max_retries = check.int_param(max_retries, "max_retries")
+        self.seconds_to_wait = check.opt_int_param(seconds_to_wait, "seconds_to_wait")
 
 
 class ObjectStoreOperationType(Enum):
-    SET_OBJECT = 'SET_OBJECT'
-    GET_OBJECT = 'GET_OBJECT'
-    RM_OBJECT = 'RM_OBJECT'
-    CP_OBJECT = 'CP_OBJECT'
+    SET_OBJECT = "SET_OBJECT"
+    GET_OBJECT = "GET_OBJECT"
+    RM_OBJECT = "RM_OBJECT"
+    CP_OBJECT = "CP_OBJECT"
 
 
 class ObjectStoreOperation(
     namedtuple(
-        '_ObjectStoreOperation',
-        'op key dest_key obj serialization_strategy_name object_store_name value_name',
+        "_ObjectStoreOperation",
+        "op key dest_key obj serialization_strategy_name object_store_name value_name",
     )
 ):
-    '''This event is used internally by Dagster machinery when values are written to and read from
+    """This event is used internally by Dagster machinery when values are written to and read from
     an ObjectStore.
 
     Users should not import this class or yield events of this type from user code.
@@ -614,7 +625,7 @@ class ObjectStoreOperation(
             employed by the operation
         object_store_name (Optional[str]): The name of the object store that performed the
             operation.
-    '''
+    """
 
     def __new__(
         cls,
@@ -629,14 +640,14 @@ class ObjectStoreOperation(
         return super(ObjectStoreOperation, cls).__new__(
             cls,
             op=op,
-            key=check.str_param(key, 'key'),
-            dest_key=check.opt_str_param(dest_key, 'dest_key'),
+            key=check.str_param(key, "key"),
+            dest_key=check.opt_str_param(dest_key, "dest_key"),
             obj=obj,
             serialization_strategy_name=check.opt_str_param(
-                serialization_strategy_name, 'serialization_strategy_name'
+                serialization_strategy_name, "serialization_strategy_name"
             ),
-            object_store_name=check.opt_str_param(object_store_name, 'object_store_name'),
-            value_name=check.opt_str_param(value_name, 'value_name'),
+            object_store_name=check.opt_str_param(object_store_name, "object_store_name"),
+            value_name=check.opt_str_param(value_name, "value_name"),
         )
 
     @classmethod
@@ -644,31 +655,31 @@ class ObjectStoreOperation(
         return cls(
             **dict(
                 {
-                    'op': inst.op.value,
-                    'key': inst.key,
-                    'dest_key': inst.dest_key,
-                    'obj': None,
-                    'serialization_strategy_name': inst.serialization_strategy_name,
-                    'object_store_name': inst.object_store_name,
-                    'value_name': inst.value_name,
+                    "op": inst.op.value,
+                    "key": inst.key,
+                    "dest_key": inst.dest_key,
+                    "obj": None,
+                    "serialization_strategy_name": inst.serialization_strategy_name,
+                    "object_store_name": inst.object_store_name,
+                    "value_name": inst.value_name,
                 },
                 **kwargs
             )
         )
 
 
-class HookExecutionResult(namedtuple('_HookExecutionResult', 'hook_name is_skipped')):
-    '''This event is used internally to indicate the execution result of a hook, e.g. whether the
+class HookExecutionResult(namedtuple("_HookExecutionResult", "hook_name is_skipped")):
+    """This event is used internally to indicate the execution result of a hook, e.g. whether the
     user-defined hook function is skipped.
 
     Args:
         hook_name (str): The name of the hook.
         is_skipped (bool): ``False`` if the hook_fn is executed, ``True`` otheriwse.
-    '''
+    """
 
     def __new__(cls, hook_name, is_skipped=None):
         return super(HookExecutionResult, cls).__new__(
             cls,
-            hook_name=check.str_param(hook_name, 'hook_name'),
-            is_skipped=check.opt_bool_param(is_skipped, 'is_skipped', default=False),
+            hook_name=check.str_param(hook_name, "hook_name"),
+            is_skipped=check.opt_bool_param(is_skipped, "is_skipped", default=False),
         )
